Organism-class: Structure of the S4 class "Organism"
Description
Structure of the S4 class Organism representing the organisms present in the environment.
Slots
lbnd- A numeric vector containing the lower bounds of the model structure.
ubnd- A numeric vector containing the upper bounds of the model structure.
type- A character vector containing the description of the organism.
medium- A character vector containing all exchange reactions of the organism.
lpobj- A sybil optimization object containing the linear programing problem.
fbasol- A list with the solutions of the flux balance analysis.
lyse- A boolean variable indicating if the organism should lyse after death.
feat- A list containing conditional features for the object (contains at the momement only biomass components for lysis).
deathrate- A numeric value giving the factor by which the growth should be reduced in every iteration (unit: fg)
growthlimit- A numeric value giving the growth limit at which the organism dies.
growtype- A character vector giving the functional type for growth (linear or exponential).
kinetics- A List containing Km and v_max values for each reactions.
speed- A integer vector representing the speed by which bacterium is moving (given by cell per iteration).
cellarea- A numeric value indicating the surface that one organism occupies (unit: mu cm^2)
cellweight- A numeric value giving the maximal dry weight of single organism (unit: fg)